@@ -13,10 +13,10 @@
 #include "lldb/Core/FileSpecList.h"
 #include "lldb/Utility/StructuredData.h"
 
-#include "lldb/Utility/FileSpec.h" // for FileSpec
-#include "lldb/lldb-forward.h"     // for SearchFilterSP, TargetSP, Modu...
+#include "lldb/Utility/FileSpec.h"
+#include "lldb/lldb-forward.h"
 
-#include <stdint.h> // for uint32_t
+#include <stdint.h>
 
 namespace lldb_private {
 class Address;
@@ -70,15 +70,6 @@ public:
     eCallbackReturnPop       // Pop one level up and continue iterating
   } CallbackReturn;
 
-  typedef enum {
-    eDepthTarget,
-    eDepthModule,
-    eDepthCompUnit,
-    eDepthFunction,
-    eDepthBlock,
-    eDepthAddress
-  } Depth;
-
   Searcher();
 
   virtual ~Searcher();
@@ -87,7 +78,7 @@ public:
                                         SymbolContext &context, Address *addr,
                                         bool complete) = 0;
 
-  virtual Depth GetDepth() = 0;
+  virtual lldb::SearchDepth GetDepth() = 0;
 
   //------------------------------------------------------------------
   /// Prints a canonical description for the searcher to the stream \a s.
@@ -192,6 +183,18 @@ public:
   //------------------------------------------------------------------
   virtual bool CompUnitPasses(CompileUnit &compUnit);
 
+  //------------------------------------------------------------------
+  /// Call this method with a Function to see if \a function passes the
+  /// filter.
+  ///
+  /// @param[in] function
+  ///    The Functions to check against the filter.
+  ///
+  /// @return
+  ///    \b true if \a function passes, and \b false otherwise.
+  //------------------------------------------------------------------
+  virtual bool FunctionPasses(Function &function);
+
   //------------------------------------------------------------------
   /// Call this method to do the search using the Searcher.
   ///
